=======
inky-pi
=======


.. image:: https://img.shields.io/pypi/v/inky_pi.svg
        :target: https://pypi.python.org/pypi/inky_pi

.. image:: https://github.com/mickeykkim/inky_pi/actions/workflows/main.yml/badge.svg
        :target: https://github.com/mickeykkim/inky_pi/actions/workflows/main.yml

.. image:: https://readthedocs.org/projects/inky-pi/badge/?version=latest
        :target: https://inky-pi.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


This program generates weather and UK train data for output to various displays (inkyWHAT e-ink display, terminal, desktop png).


* Free software: MIT
* Documentation: https://inky-pi.readthedocs.io.


Features
--------

* Displays weather data using Weather Underground API
* Displays UK train data using National Rail API

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
